@@ -21,11 +21,15 @@ public:
   BlogView(const std::string& basePath, const std::string& sqliteDb,
 	   const std::string& rssFeedUrl, Wt::WContainerWidget *parent = 0);
 
+  Wt::WString user();
   void login(const std::string& user);
   void logout();
 
+  Wt::Signal<Wt::WString>& userChanged() { return userChanged_; }
+
 private:
   BlogImpl *impl_;
+  Wt::Signal<Wt::WString> userChanged_;
 };
 
 #endif // BLOG_VIEW_H_
