@@ -7,11 +7,17 @@
 #ifndef SIMPLECHATSERVER_H_
 #define SIMPLECHATSERVER_H_
 
-#include <Wt/WObject>
+#include <boost/noncopyable.hpp>
+
 #include <Wt/WSignal>
 #include <Wt/WString>
 
+namespace Wt {
+  class WServer;
+}
+
 #include <set>
+#include <map>
 #include <boost/thread.hpp>
 
 /**
@@ -26,7 +32,7 @@ class ChatEvent
 public:
   /*! \brief Enumeration for the event type.
    */
-  enum Type { Login, Logout, Message };
+  enum Type { Login, Logout, Rename, Message };
 
   /*! \brief Get the event type.
    */
@@ -40,6 +46,10 @@ public:
    */
   const Wt::WString& message() const { return message_; }
 
+  /*! \brief Get the extra data for this event.
+   */
+  const Wt::WString& data() const { return data_; }
+
   /*! \brief Get the message formatted as HTML, rendered for the given user.
    */
   const Wt::WString formattedHTML(const Wt::WString& user) const;
@@ -47,6 +57,7 @@ public:
 private:
   Type type_;
   Wt::WString user_;
+  Wt::WString data_;
   Wt::WString message_;
 
   /*
@@ -56,32 +67,40 @@ private:
     : type_(Message), user_(user), message_(message)
   { }
 
-  ChatEvent(Type type, const Wt::WString& user)
-    : type_(type), user_(user)
+  ChatEvent(Type type, const Wt::WString& user,
+	    const Wt::WString& data = Wt::WString::Empty)
+    : type_(type), user_(user), data_(data)
   { }
 
   friend class SimpleChatServer;
 };
 
+typedef boost::function<void (const ChatEvent&)> ChatEventCallback;
+
 /*! \brief A simple chat server
  */
-class SimpleChatServer : public Wt::WObject
+class SimpleChatServer : boost::noncopyable
 {
 public:
   /*! \brief Create a new chat server.
    */
-  SimpleChatServer();
+  SimpleChatServer(Wt::WServer& server);
 
   /*! \brief Try to login with given user name.
    *
-   * Returns false if the login was not successfull.
+   * Returns false if the login was not successfull. The passed callback method
+   * is posted to when a new chat event is received.
    */
-  bool login(const Wt::WString& user);
+  bool login(const Wt::WString& user, const ChatEventCallback& handleEvent);
 
   /*! \brief Logout from the server.
    */
   void logout(const Wt::WString& user);
 
+  /*! \brief Changes the name.
+   */
+  bool changeName(const Wt::WString& user, const Wt::WString& newUser);
+
   /*! \brief Get a suggestion for a guest user name.
    */
   Wt::WString suggestGuest();
@@ -90,12 +109,6 @@ public:
    */
   void sendMessage(const Wt::WString& user, const Wt::WString& message);
 
-  /*! \brief %Signal that will convey chat events.
-   *
-   * Every client should connect to this signal, and process events.
-   */
-  Wt::Signal<ChatEvent>& chatEvent() { return chatEvent_; }
-
   /*! \brief Typedef for a collection of user names.
    */
   typedef std::set<Wt::WString> UserSet;
@@ -105,10 +118,18 @@ public:
   UserSet users();
 
 private:
-  Wt::Signal<ChatEvent>         chatEvent_;
-  boost::mutex                  mutex_;
+  struct UserInfo {
+    std::string sessionId;
+    ChatEventCallback eventCallback;
+  };
 
-  UserSet                       users_;
+  typedef std::map<Wt::WString, UserInfo> UserMap;
+
+  Wt::WServer& server_;
+  boost::recursive_mutex mutex_;
+  UserMap users_;
+
+  void postChatEvent(const ChatEvent& event);
 };
 
 /*@}*/
