@@ -41,13 +41,15 @@ public:
 	     const std::string &classname4,
 	     WContainerWidget *parent) const;
 
+  EventDisplayer* eventDisplayer() { return ed_; }
+
 protected:
   EventDisplayer *ed_;
 
 private:
   bool hasSubMenu_;
 
-  std::string doxygenAnchor(const std::string &classname) const;
+  std::string docAnchor(const std::string &classname) const;
   std::string title(const std::string &classname) const;
   std::string escape(const std::string &name) const;
 };
