@@ -28,6 +28,7 @@ private:
   Wt::WWidget *wComboBox();
   Wt::WWidget *wSelectionBox();
   Wt::WWidget *wLineEdit();
+  Wt::WWidget *wSpinBox();
   Wt::WWidget *wTextArea();
   Wt::WWidget *wCalendar();
   Wt::WWidget *wDatePicker();
@@ -35,7 +36,9 @@ private:
   Wt::WWidget *wSuggestionPopup();
   Wt::WWidget *wTextEdit();
   Wt::WWidget *wFileUpload();
+#ifndef WT_TARGET_JAVA
   Wt::WWidget *wPopupMenu();
+#endif
 
   void addColorElement(Wt::WStandardItemModel* model,
 		       std::string name, 
