@@ -35,13 +35,17 @@ private:
   Wt::WWidget *models();
   Wt::WWidget *proxyModels();
   Wt::WWidget *viewsCombo();
-  Wt::WWidget *viewsExtTable();
+  Wt::WWidget *viewsTable();
   Wt::WWidget *viewsTree();
   Wt::WWidget *viewsChart();
 
+
   Wt::WStringListModel *stringList_;
+#ifndef WT_TARGET_JAVA
   Wt::Ext::ComboBox *extComboBox_;
   void comboBoxAdd();
+#endif
+
   void changeRegexp() {
     filteredCocktails->setFilterRegExp(regexpFilter->text());
     filteredSortedCocktails->setFilterRegExp(regexpFilter->text());
