@@ -26,11 +26,8 @@ public:
 private:
   Wt::WWidget *wGoogleMap();
   Wt::WWidget *wSound();
-  void 
-  roadDescription(std::vector<Wt::WGoogleMap::Coordinate>& roadDescription);
-
-  void googleMapDoubleClicked(Wt::WGoogleMap::Coordinate c);
-  void googleMapClicked(Wt::WGoogleMap::Coordinate c);
+  Wt::WWidget *wVideo();
+  Wt::WWidget *wFlashObject();
 };
 
 #endif
