@@ -10,6 +10,9 @@
 
 #include "ControlsWidget.h"
 
+#include <Wt/WString>
+#include <Wt/WEvent>
+
 class StyleLayout : public ControlsWidget
 {
 public:
@@ -19,6 +22,9 @@ public:
 
 private:
   WWidget *css();
+  WWidget *wLoadingIndicator();
+  void loadingIndicatorSelected(Wt::WString indicator);
+  void load(Wt::WMouseEvent);
   WWidget *wBoxLayout();
   WWidget *wGridLayout();
   WWidget *wBorderLayout();
