@@ -51,7 +51,8 @@ public:
 private:
   void load() {
     WContainerWidget::load();
-    addWidget(f_());
+    if (count() == 0)
+      addWidget(f_());
   }
 
   Function f_;
@@ -76,7 +77,7 @@ public:
 
 protected:
   virtual WWidget *examples() = 0;
-  virtual WWidget *download() = 0;
+  virtual WWidget *createQuoteForm() = 0;
   virtual WWidget *sourceViewer(const std::string &deployPath) = 0;
   virtual std::string filePrefix() const = 0;
 
@@ -108,6 +109,8 @@ private:
   WWidget *documentation();
   WWidget *community();
   WWidget *otherLanguage();
+  WWidget *download();
+  WWidget *quoteForm();
 
   WMenu *mainMenu_;
 
@@ -122,6 +125,7 @@ private:
   void setLanguageFromPath();
   void setup();
   void logInternalPath(const std::string& path);
+  void chatSetUser(const WString& name);
 
   WContainerWidget *sideBarContent_;
   
