@@ -58,6 +58,8 @@ public:
   /// Stop all asynchronous operations associated with the connection.
   virtual void stop() = 0;
 
+  void close();
+
   /// Like CGI's Url scheme: http or https
   virtual std::string urlScheme() = 0;
 
@@ -75,6 +77,8 @@ public: // huh?
   void handleReadRequest0();
   void handleReadBody(const asio_error_code& e,
 		      std::size_t bytes_transferred);
+  void handleReadBody();
+  bool readAvailable();
 
 protected:
   void setTimeout(int seconds);
@@ -95,7 +99,8 @@ private:
    * Asynchronoulsy reading a request body
    */
   virtual void startAsyncReadBody(Buffer& buffer, int timeout) = 0;
-  void handleReadBody();
+  void handleError(const asio_error_code& e);
+  void sendStockReply(Reply::status_type code);
 
   /*
    * Asynchronoulsy writing a response
@@ -134,6 +139,7 @@ private:
 };
 
 typedef boost::shared_ptr<Connection> ConnectionPtr;
+typedef boost::weak_ptr<Connection> ConnectionWeakPtr;
 
 } // namespace server
 } // namespace http
