@@ -18,16 +18,18 @@ namespace server {
 class HTTPRequest : public Wt::WebRequest
 {
 public:
-  HTTPRequest(WtReplyPtr wtReply);
+  HTTPRequest(WtReplyPtr wtReply, const Wt::EntryPoint *entryPoint);
 
-  virtual void flush(ResponseState state, CallbackFunction callback = 0,
-		     void *callbackData = 0);
+  virtual void flush(ResponseState state, CallbackFunction callback);
+  virtual void readWebSocketMessage(CallbackFunction callback);
+  virtual bool webSocketMessagePending() const;
 
-  virtual std::istream& in() { return instream_; }
+  virtual std::istream& in() { return reply_->cin(); }
   virtual std::ostream& out() { return outstream_; }
   virtual std::ostream& err() { return std::cerr; }
 
   virtual void setStatus(int status);
+  virtual void setContentLength(::int64_t length);
 
   virtual void addHeader(const std::string& name, const std::string& value);
   virtual void setContentType(const std::string& value);
@@ -43,10 +45,10 @@ public:
   virtual std::string pathInfo() const;
   virtual std::string remoteAddr() const;
   virtual std::string urlScheme() const;
+  virtual bool isSynchronous() const;
 
 private:
   WtReplyPtr reply_;
-  std::istream &instream_;
   std::stringstream outstream_;
 };
 
