@@ -19,8 +19,6 @@ public:
 
   virtual WebRequest *getNextRequest(int timeoutsec);
 
-  virtual void addSocketNotifier(WSocketNotifier *notifier);
-  virtual void removeSocketNotifier(WSocketNotifier *notifier);
 };
 
 }
