@@ -19,6 +19,7 @@
 
 #include <time.h>
 
+#include <list>
 #include <string>
 #include <vector>
 
@@ -41,52 +42,57 @@ namespace asio = boost::asio;
 
 #include "Buffer.h"
 #include "WHttpDllDefs.h"
-
-#ifdef WIN32
-struct tm* gmtime_r(const time_t* t, struct tm* r);
-#endif
-
+#include "Request.h"
 
 namespace http {
 namespace server {
 
+class Configuration;
 class Connection;
 class Reply;
-class Request;
 
+typedef boost::shared_ptr<Connection> ConnectionPtr;
 typedef boost::shared_ptr<Reply> ReplyPtr;
 
+typedef boost::weak_ptr<Connection> ConnectionWeakPtr;
+
 class WTHTTP_API Reply : public boost::enable_shared_from_this<Reply>
 {
 public:
-  Reply(const Request& request);
+  Reply(const Request& request, const Configuration& config);
   virtual ~Reply();
 
   enum status_type
   {
+    switching_protocols = 101,
     ok = 200,
     created = 201,
     accepted = 202,
     no_content = 204,
+    partial_content = 206,
     multiple_choices = 300,
     moved_permanently = 301,
-    moved_temporarily = 302,
+    found = 302,
+    see_other = 303,
     not_modified = 304,
+    moved_temporarily = 307,
     bad_request = 400,
     unauthorized = 401,
     forbidden = 403,
     not_found = 404,
+    request_entity_too_large = 413,
+    requested_range_not_satisfiable = 416,
     internal_server_error = 500,
     not_implemented = 501,
     bad_gateway = 502,
     service_unavailable = 503
   };
 
-  virtual void consumeRequestBody(Buffer::const_iterator begin,
-				  Buffer::const_iterator end,
-				  bool endOfRequest) = 0;
+  virtual void consumeData(Buffer::const_iterator begin,
+			   Buffer::const_iterator end,
+			   Request::State state) = 0;
 
-  void setConnection(Connection *connection);
+  void setConnection(ConnectionPtr connection);
   bool nextBuffers(std::vector<asio::const_buffer>& result);
   bool closeConnection() const { return closeConnection_; }
   void setCloseConnection() { closeConnection_ = true; }
@@ -96,20 +102,25 @@ public:
   bool waitMoreData() const { return waitMoreData_; }
   void setWaitMoreData(bool how);
   void send();
+  virtual void release();
+
+  const Configuration& configuration() { return configuration_; }
 
   void logReply(Wt::WLogger& logger);
 
+  virtual status_type responseStatus() = 0;
+
 protected:
   const Request& request_;
+  const Configuration& configuration_;
   std::string remoteAddress_;
   std::string requestMethod_;
   std::string requestUri_;
   int requestMajor_, requestMinor_;
 
-  virtual status_type responseStatus() = 0;
   virtual std::string contentType() = 0;
   virtual std::string location();
-  virtual boost::intmax_t contentLength() = 0;
+  virtual ::int64_t contentLength() = 0;
 
   virtual asio::const_buffer nextContentBuffer() = 0;
 
@@ -119,16 +130,12 @@ protected:
 
   static std::string httpDate(time_t t);
 
-#ifdef WT_THREADED
-  boost::recursive_mutex mutex_;
-#endif // WT_THREADED
+  ConnectionPtr getConnection() { return connection_.lock(); }
 
-  Connection *connection() { return connection_; }
 private:
   std::vector<std::pair<std::string, std::string> > headers_;
 
-  // protected by replyMutex_
-  Connection *connection_;
+  ConnectionWeakPtr connection_;
 
 #ifndef WIN32
   struct timeval startTime_;
@@ -141,8 +148,8 @@ private:
   bool waitMoreData_;
   bool finishing_;
 
-  boost::intmax_t contentSent_;
-  boost::intmax_t contentOriginalSize_;
+  ::int64_t contentSent_;
+  ::int64_t contentOriginalSize_;
 
   ReplyPtr relay_;
   std::list<std::string> bufs_;
@@ -154,6 +161,7 @@ private:
 			       int& encodedSize);
 #ifdef WTHTTP_WITH_ZLIB
   void initGzip();
+  bool gzipBusy_;
   z_stream gzipStrm_;
 #endif
 };
