@@ -23,10 +23,6 @@
 namespace asio = boost::asio;
 #endif // HTTP_WITH_SSL
 
-#if defined(WT_THREADED) && BOOST_VERSION < 103600
-#include <boost/asio/detail/select_reactor.hpp>
-#endif // defined(WT_THREADED) && BOOST_VERSION < 103600
-
 #include <string>
 #include <boost/noncopyable.hpp>
 #include <boost/version.hpp>
@@ -64,30 +60,27 @@ public:
   /// Run the server's io_service loop.
   void run();
 
+  /// Start the server (called from constructor)
+  void start();
+
   /// Stop the server.
   void stop();
 
-  /// Select for read on descriptor
-  void select_read(int descriptor);
+  /// Assumes accept sockets have been closed and reopens them.
+  void resume();
 
-  /// Select for read on descriptor
-  void select_write(int descriptor);
-
-  /// Select for exceptions on descriptor
-  void select_except(int descriptor);
-
-  /// Stop selecting on the descriptor
-  void stop_select(int descriptor);
+  /// Posts an event to the thread pool
+  void post(const boost::function<void ()>& function);
 
   /// Returns the http port number.
   int httpPort() const;
 
-  static Server* instance() { return instance_; }
-
   Wt::WebController *controller() { return controller_; }
 
   const Configuration &configuration() { return config_; }
 
+  asio::io_service &service() { return io_service_; }
+
 private:
   /// Starts accepting http/https connections
   void startAccept();
@@ -98,6 +91,9 @@ private:
   /// Handle a request to stop the server.
   void handleStop();
 
+  /// Handle a request to resume the server.
+  void handleResume();
+
   /// The server's configuration
   Configuration config_;
 
@@ -110,6 +106,9 @@ private:
   /// The strand for handleTcpAccept(), handleSslAccept() and handleStop()
   asio::strand accept_strand_;
 
+  /// The strand for post()
+  asio::strand post_strand_;
+
   /// Acceptor used to listen for incoming http connections.
   asio::ip::tcp::acceptor tcp_acceptor_;
 
@@ -127,21 +126,6 @@ private:
   SslConnectionPtr new_sslconnection_;
 #endif // HTTP_WITH_SSL
 
-#ifdef WT_THREADED
-#if BOOST_VERSION < 103600
-  /// Reactor that listens for selects() on auxiliary sockets. 
-  asio::detail::select_reactor<false> select_reactor_;
-#else
-  struct SelectInfo {
-    asio::ip::tcp::socket *readSocket, *writeSocket;
-
-    SelectInfo() : readSocket(0), writeSocket(0) { }
-  };
-  std::map<int, SelectInfo> notifyingSockets_;
-  boost::recursive_mutex    notifyingSocketsMutex_;
-#endif
-#endif
-
   /// The connection manager which owns all live connections.
   ConnectionManager connection_manager_;
 
@@ -151,13 +135,7 @@ private:
   /// The handler for all incoming requests.
   RequestHandler request_handler_;
 
-  enum SelectOp { Read, Write };
-  bool socketSelected(int descriptor, const asio_error_code& e,
-		      std::size_t bytes_transferred, SelectOp op);
-
   Wt::WebController *controller_;
-
-  static Server *instance_;
 };
 
 } // namespace server
