@@ -35,16 +35,16 @@ class StaticReply : public Reply
 {
 public:
   StaticReply(const std::string &full_path, const std::string &extension,
-	      const Request& request, const std::string &err_root);
+	      const Request& request, const Configuration& configuration);
 
-  virtual void consumeRequestBody(Buffer::const_iterator begin,
-				  Buffer::const_iterator end,
-				  bool endOfRequest);
+  virtual void consumeData(Buffer::const_iterator begin,
+			   Buffer::const_iterator end,
+			   Request::State state);
 
 protected:
   virtual status_type responseStatus();
   virtual std::string contentType();
-  virtual boost::intmax_t contentLength();
+  virtual ::int64_t contentLength();
 
   virtual asio::const_buffer nextContentBuffer();
 
@@ -52,13 +52,19 @@ private:
   std::string     path_;
   std::string     extension_;
   std::ifstream   stream_;
-  boost::intmax_t fileSize_;
+  ::int64_t fileSize_;
 
   char buf_[64 * 1024];
 
   std::string computeModifiedDate() const;
   std::string computeETag() const;
   static std::string computeExpires();
+
+  void parseRangeHeader();
+  bool hasRange_;
+  ::int64_t rangeBegin_;
+  ::int64_t rangeEnd_;
+
 };
 
 } // namespace server
