@@ -32,26 +32,25 @@ namespace server {
 class WTHTTP_API StockReply : public Reply
 {
 public:
-  StockReply(const Request& request, status_type status);
   StockReply(const Request& request, status_type status,
-	     std::string extraContent);
+	     const Configuration& configuration);
   StockReply(const Request& request, status_type status,
-	     const std::string &extraContent, const std::string &err_root);
+	     std::string extraContent,
+	     const Configuration& configuration);
 
-  virtual void consumeRequestBody(Buffer::const_iterator begin,
-				  Buffer::const_iterator end,
-				  bool endOfRequest);
+  virtual void consumeData(Buffer::const_iterator begin,
+			   Buffer::const_iterator end,
+			   Request::State state);
 
 protected:
   virtual status_type responseStatus();
   virtual std::string contentType();
-  virtual boost::intmax_t contentLength();
+  virtual ::int64_t contentLength();
 
   virtual asio::const_buffer nextContentBuffer();  
 
 private:
   status_type status_;
-  std::string err_root_;
   std::string content_;
   bool transmitted_;
 };
