@@ -13,7 +13,7 @@
 #include <vector>
 
 #include "Reply.h"
-#include "Connection.h"
+#include "../web/Configuration.h"
 
 namespace http {
 namespace server {
@@ -21,6 +21,7 @@ namespace server {
 class StockReply;
 class HTTPRequest;
 class WtReply;
+class Configuration;
 
 typedef boost::shared_ptr<WtReply> WtReplyPtr;
 
@@ -28,25 +29,27 @@ typedef boost::shared_ptr<WtReply> WtReplyPtr;
 class WtReply : public Reply
 {
 public:
-  typedef void (*CallbackFunction)(void *cbData);
+  typedef boost::function<void(void)> CallbackFunction;
 
   WtReply(const Request& request, const Wt::EntryPoint& ep,
-    const Configuration &config);
+	  const Configuration &config);
   ~WtReply();
 
-  virtual void consumeRequestBody(Buffer::const_iterator begin,
-				  Buffer::const_iterator end,
-				  bool endOfRequest);
+  virtual void consumeData(Buffer::const_iterator begin,
+			   Buffer::const_iterator end,
+			   Request::State state);
 
   void setStatus(int status);
+  void setContentLength(::int64_t length);
   void setContentType(const std::string& type);
   void setLocation(const std::string& location);
-  void send(const std::string& text, CallbackFunction callBack, void *cbData);
+  void send(const std::string& text, CallbackFunction callBack);
+  void readWebSocketMessage(CallbackFunction callBack);
+  bool readAvailable();
 
   std::istream& cin() { return *cin_; }
   const Request& request() const { return request_; }
-
-  virtual bool expectMoreData();
+  std::string urlScheme() const { return urlScheme_; }
 
 protected:
   const Wt::EntryPoint& entryPoint_;
@@ -56,17 +59,31 @@ protected:
   std::string       cout_, nextCout_;
   std::string       contentType_;
   std::string       location_;
-  bool              responseSent_, sending_;
+  std::string       urlScheme_;
+  bool              responseSent_;
   status_type       status_;
-  volatile CallbackFunction  fetchMoreData_;
-  void *            callBackData_;
+  ::int64_t         contentLength_, bodyReceived_;
+  bool              sendingMessages_;
+  CallbackFunction  fetchMoreDataCallback_, readMessageCallback_;
+  HTTPRequest      *httpRequest_;
+  bool              sending_;
 
   virtual status_type     responseStatus();
   virtual std::string     contentType();
   virtual std::string     location();
-  virtual boost::intmax_t contentLength();
+  virtual ::int64_t       contentLength();
+  virtual void            release();
 
   virtual asio::const_buffer nextContentBuffer();  
+
+private:
+  void consumeRequestBody(Buffer::const_iterator begin,
+			  Buffer::const_iterator end,
+			  Request::State state);
+
+  void consumeWebSocketMessage(Buffer::const_iterator begin,
+			       Buffer::const_iterator end,
+			       Request::State state);
 };
 
 } // namespace server
