@@ -16,7 +16,7 @@
 #include "Wt/WLogger"
 
 #include "WebSession.h"
-#include "WtRandom.h"
+#include "Wt/WRandom"
 
 namespace rapidxml {
   template<class Ch> class xml_node;
@@ -67,19 +67,29 @@ public:
     DedicatedProcess,
     SharedProcess
   };
+
   enum SessionTracking { 
     CookiesURL,
     URL
   };
+
   enum ServerType {
     WtHttpdServer,
-    FcgiServer
+    FcgiServer,
+    IsapiServer
+  };
+
+  enum ErrorReporting {
+    NoErrors,
+    ErrorMessage,
+    ErrorMessageWithStack
   };
 
   typedef std::map<std::string, std::string> PropertyMap;
   typedef std::vector<std::string> AgentList;
 
   Configuration(const std::string& applicationPath,
+                const std::string& approot,
 		const std::string& configurationFile,
 		ServerType serverType,
 		const std::string& startupMessage);
@@ -99,29 +109,39 @@ public:
   int                numProcesses() const { return numProcesses_; }
   int                numThreads() const { return numThreads_; }
   int                maxNumSessions() const { return maxNumSessions_; }
-  int                maxRequestSize() const { return maxRequestSize_; }
+  ::int64_t          maxRequestSize() const { return maxRequestSize_; }
+  ::int64_t          isapiMaxMemoryRequestSize() const { return isapiMaxMemoryRequestSize_; }
   SessionTracking    sessionTracking() const { return sessionTracking_; }
   bool               reloadIsNewSession() const { return reloadIsNewSession_; }
   int                sessionTimeout() const { return sessionTimeout_; }
+  void               setSessionTimeout(int sessionTimeout);
+  int		     indicatorTimeout() const { return indicatorTimeout_; }
   int                serverPushTimeout() const { return serverPushTimeout_; }
   std::string        valgrindPath() const { return valgrindPath_; }
-  bool               debug() const { return debug_; }
+  ErrorReporting     errorReporting() const { return errorReporting_; }
+  bool               debug() const { return errorReporting_ != ErrorMessage; }
+  bool               logTime() const { return logTime_; }
   std::string        runDirectory() const { return runDirectory_; }
+  ServerType         serverType() const { return serverType_; }
   int                sessionIdLength() const { return sessionIdLength_; }
   std::string        sessionIdPrefix() const { return sessionIdPrefix_; }
   const PropertyMap& properties() const { return properties_; }
-  const std::string* property(const std::string& name) const; 
-  ServerType         serverType() const { return serverType_; }
+  const std::string* property(const std::string& name) const;
+  bool               readConfigurationProperty(const std::string& name,
+					       std::string& value) const;
+  std::string        appRoot() const;
   bool               sendXHTMLMimeType() const { return xhtmlMimeType_; }
   bool               behindReverseProxy() const { return behindReverseProxy_; }
   std::string        redirectMessage() const { return redirectMsg_; }
   bool               serializedEvents() const { return serializedEvents_; }
+  bool               webSockets() const { return webSockets_; }
   bool               inlineCss() const { return inlineCss_; }
   bool               ajaxAgentWhiteList() const { return ajaxAgentWhiteList_; }
   const AgentList&   ajaxAgentList() const { return ajaxAgentList_; }
   const AgentList&   botList() const { return botList_; }
   bool               persistentSessions() const { return persistentSessions_; }
   bool               progressiveBoot() const { return progressiveBoot_; }
+  bool               splitScript() const { return splitScript_; }
 
   WLogger&           logger() { return logger_; }
   WLogEntry          log(const std::string& type) const;
@@ -129,16 +149,17 @@ public:
   int                pid() const { return pid_; }
 
   /*
-   * Generate a unique session Id.
-   *
    * For a FastCGI server, this also creates a session file.
    */
+  static std::string generateRandomId(int length);
+
   std::string generateSessionId();
 
   std::string sessionSocketPath(const std::string& sessionId);
 
 private:
   std::string     applicationPath_;
+  std::string     approot_;
 
 #ifndef WT_TARGET_JAVA
   EntryPointList     entryPoints_;
@@ -149,13 +170,16 @@ private:
   int             numProcesses_;
   int             numThreads_;
   int             maxNumSessions_;
-  int             maxRequestSize_;
+  ::int64_t       maxRequestSize_;
+  ::int64_t       isapiMaxMemoryRequestSize_;
   SessionTracking sessionTracking_;
   bool            reloadIsNewSession_;
   int             sessionTimeout_;
+  int		  indicatorTimeout_;
   int             serverPushTimeout_;
   std::string     valgrindPath_;
-  bool            debug_;
+  ErrorReporting  errorReporting_;
+  bool            logTime_;
   std::string     runDirectory_;
   int             sessionIdLength_;
   std::string     sessionIdPrefix_;
@@ -164,14 +188,15 @@ private:
   bool            behindReverseProxy_;
   std::string     redirectMsg_;
   bool            serializedEvents_;
+  bool		  webSockets_;
   bool            inlineCss_;
   AgentList       ajaxAgentList_, botList_;
   bool            ajaxAgentWhiteList_;
   bool            persistentSessions_;
   bool            progressiveBoot_;
+  bool            splitScript_;
 
   int		  pid_;
-  WtRandom        random_;
   WLogger         logger_;
 
   void readApplicationSettings(rapidxml::xml_node<char> *app);
