@@ -28,6 +28,7 @@ enum Property { PropertyInnerHTML, PropertyAddedInnerHTML,
 		PropertyMultiple, PropertyTarget, PropertyIndeterminate,
 		PropertySrc, PropertyText, PropertyScript,
 		PropertyColSpan, PropertyRowSpan, PropertyReadOnly,
+		PropertyTabIndex,
 		PropertyClass,
 		PropertyStyle,
 		PropertyStyleWidthExpression,
@@ -41,6 +42,8 @@ enum Property { PropertyInnerHTML, PropertyAddedInnerHTML,
 		PropertyStyleTop, PropertyStyleBottom,
 		PropertyStyleVerticalAlign, PropertyStyleTextAlign,
 		PropertyStylePadding,
+		PropertyStylePaddingTop, PropertyStylePaddingRight,
+		PropertyStylePaddingBottom, PropertyStylePaddingLeft,
 		PropertyStyleMarginTop, PropertyStyleMarginRight,
 		PropertyStyleMarginBottom, PropertyStyleMarginLeft,
 		PropertyStyleCursor, 
@@ -49,6 +52,7 @@ enum Property { PropertyInnerHTML, PropertyAddedInnerHTML,
 		PropertyStyleColor,
 		PropertyStyleOverflowX,
 		PropertyStyleOverflowY,
+		PropertyStyleOpacity,
 		PropertyStyleFontFamily,
 		PropertyStyleFontStyle,
 		PropertyStyleFontVariant,
@@ -61,7 +65,11 @@ enum Property { PropertyInnerHTML, PropertyAddedInnerHTML,
 		PropertyStyleBackgroundPosition,
 		PropertyStyleTextDecoration, PropertyStyleWhiteSpace,
 		PropertyStyleTableLayout, PropertyStyleBorderSpacing,
-		PropertyStyleVisibility, PropertyStyleDisplay };
+		PropertyStyleZoom,
+		PropertyStyleVisibility, PropertyStyleDisplay,
+
+		/* CSS 3 */
+		PropertyStyleBoxSizing };
 
 class WT_API DomElement
 {
@@ -73,6 +81,8 @@ public:
   ~DomElement();
 
   static std::string urlEncodeS(const std::string& url);
+  static std::string urlEncodeS(const std::string& url,
+                                const std::string& allowed);
 
   Mode mode() const { return mode_; }
 
@@ -113,6 +123,7 @@ public:
 		const std::string& signalName,
 		bool isExposed = false);
   void setEvent(const char *eventName, const std::string& jsCode);
+  void addEvent(const char *eventName, const std::string& jsCode);
 
   struct EventAction
   {
@@ -140,11 +151,12 @@ public:
   /*
    * only for ModeUpdate
    */
-  void removeAllChildren();
+  void removeAllChildren(int firstChild = 0);
   void removeFromParent();
   void replaceWith(DomElement *newElement);
   void unstubWith(DomElement *newElement, bool hideWithDisplay);
   void insertBefore(DomElement *sibling);
+  void unwrap();
 
   void setDiscardWithParent(bool discard);
   bool discardWithParent() const { return discardWithParent_; }
@@ -189,6 +201,9 @@ public:
   static void htmlAttributeValue(std::ostream& out, const std::string& s);
   static bool isSelfClosingTag(const std::string& tag);
   static bool isSelfClosingTag(DomElementType element);
+  static DomElementType parseTagName(const std::string& tag);
+  static const std::string& cssName(Property property);
+  static bool isDefaultInline(DomElementType type);
 
   std::string javaScript() const { return javaScript_.str(); }
 
@@ -202,6 +217,7 @@ public:
 
   std::string createVar() const;
 
+
 private:
   struct EventHandler {
     std::string jsCode;
@@ -234,11 +250,11 @@ private:
 
   Mode         mode_;
   bool         wasEmpty_;
-  bool         deleted_;         // when removeFromParent() is called
-  bool	       removeAllChildren_;
+  int	       removeAllChildren_;
   bool         hideWithDisplay_;
   bool         minMaxSizeProperties_;
   bool         unstubbed_;
+  bool         unwrapped_;
   DomElement  *replaced_;        // when replaceWith() is called
   DomElement  *insertBefore_;
   DomElementType type_;
@@ -265,6 +281,7 @@ private:
 
   std::vector<ChildInsertion> childrenToAdd_;
   std::vector<std::string> childrenToSave_;
+  std::vector<DomElement *> updatedChildren_;
   EscapeOStream childrenHtml_;
   TimeoutList timeouts_;
 
