@@ -17,6 +17,10 @@
 
 #include <Wt/WDllDefs.h>
 
+#ifdef _MSC_VER
+#include <float.h>
+#endif
+
 namespace Wt {
 
   class WString;
@@ -28,13 +32,17 @@ namespace Wt {
 extern WT_API std::string createTempFileName();
 
 // appends the character to the string if it does not end with it
-extern std::string terminate(const std::string& s, char c);
+extern std::string append(const std::string& s, char c);
+extern std::string prepend(const std::string& s, char c);
 
 // in-place replace functions
 extern std::string& replace(std::string& s, char c, const std::string& r);
 extern std::string& replace(std::string& s, const std::string& c,
 			    const std::string& r);
 
+// lower case an UTF-8 string
+extern std::string lowerCase(const std::string& s);
+
 // sanitize unicode 
 extern void sanitizeUnicode(EscapeOStream& sout, const std::string& text);
 
@@ -55,7 +63,7 @@ inline bool startsWith(const char *a, const char *b, int n) {
 
 inline int length(const std::stringstream& s) {
 #ifndef WT_CNOR
-  return s.rdbuf()->in_avail();
+  return (int)s.rdbuf()->in_avail();
 #else
   return 0;
 #endif
@@ -72,7 +80,7 @@ inline int indexOf(const std::vector<T>& v, const T& value)
   if (i == v.end())
     return -1;
   else
-    return i - v.begin();
+    return static_cast<int>(i - v.begin());
 }
 
 template<typename T>
@@ -87,10 +95,20 @@ inline bool erase(std::vector<T>& v, const T& value)
     return false;
 }
 
+template<typename K, typename V>
+void eraseAndNext(std::map<K, V>& m, typename std::map<K, V>::iterator& i)
+{
+#ifndef WT_TARGET_JAVA
+  m.erase(i++);
+#endif // WT_TARGET_JAVA
+}
+
 template<typename T>
 inline void insert(std::vector<T>& result, const std::vector<T>& elements)
 {
+#ifndef WT_CNOR
   result.insert(result.end(), elements.begin(), elements.end());
+#endif // WT_CNOR
 }
 
 template<typename T>
@@ -118,10 +136,25 @@ inline void stable_sort(std::vector<T>& result, const Compare& compare)
 }
 
 template <typename T, typename Compare>
-inline int insertion_point(const std::vector<T>& v, const T& item,
-			   Compare compare)
+inline unsigned insertion_point(const std::vector<T>& v, const T& item,
+				Compare compare)
 {
-  return std::lower_bound(v.begin(), v.end(), item, compare) - v.begin();
+  return static_cast<unsigned>(
+    std::lower_bound(v.begin(), v.end(), item, compare) - v.begin());
+}
+
+template <typename T>
+inline unsigned lower_bound(const std::vector<T>& v, const T& item)
+{
+  return static_cast<unsigned>(
+    std::lower_bound(v.begin(), v.end(), item) - v.begin());
+}
+
+template <typename T>
+inline unsigned upper_bound(const std::vector<T>& v, const T& item)
+{
+  return static_cast<unsigned>(
+    std::upper_bound(v.begin(), v.end(), item) - v.begin());
 }
 
 template <typename K, typename V, typename T>
@@ -156,9 +189,10 @@ extern char *round_str(double d, int digits, char *buf);
 // Only for Java target
 extern std::string toHexString(int i);
 
-// Split a string in a vector of strings, on every given token
-extern std::vector<std::string> tokenizer(const std::string &in,
-					  const std::string &sep);
+// Splits a string in a set of strings, on every given token
+extern void split(std::set<std::string>& tokens,
+		  const std::string &in, const char *sep,
+		  bool compress_adjacent_tokens);
 
 // Replace all occurences of the 'from' char to the 'to' char in 'v'
 extern void replaceAll(std::string& v, char from, char to);
@@ -168,9 +202,21 @@ extern void unescapeHexTokens(std::string& v);
 extern void urlDecode(std::string &s);
 
 extern std::string urlEncode(const std::string& url);
+extern std::string urlEncode(const std::string& url,
+                             const std::string& allowed);
+extern std::string dataUrlDecode(const std::string& url,
+				 std::vector<unsigned char> &data);
 
+extern std::string EncodeHttpHeaderField(const std::string &fieldname,
+                                         const Wt::WString &fieldValue);
 inline bool isNaN(double d) {
+#ifdef _MSC_VER
+  // received bug reports that on 64 bit windows, MSVC2005
+  // generates wrong code for d != d.
+  return _isnan(d) != 0;
+#else
   return !(d == d);  
+#endif
 }
 
 /*
@@ -193,6 +239,26 @@ template<typename T> inline int size(const T& vector) {
 #endif // WT_TARGET_JAVA
 }
 
+template<typename Map, typename K, typename V> 
+inline void find(const Map& map, const K& key, V& result)
+{
+  #ifndef WT_TARGET_JAVA
+  std::pair<typename Map::const_iterator, typename Map::const_iterator> range 
+    = map.equal_range(key);
+  
+  for (typename Map::const_iterator i = range.first; i != range.second; ++i)
+    result.push_back(i->second);
+  #endif
+}
+
+void stringToDouble(const char *str, char **end, double &value);
+
+std::string readJavaScriptFile(const std::string& fname);
+
+int calculatePluralCase(const std::string &expression, ::uint64_t amount);
+
+WString formatFloat(const WString &format, double value);
+
   }
 }
 
