@@ -41,13 +41,12 @@ public:
 
   bool visibleOnly() const { return visibleOnly_; }
   void setVisibleOnly(bool how) { visibleOnly_ = how; }
+  void setRendered(bool how) { rendered_ = how; }
 
   void needUpdate(WWidget *w, bool laterOnly);
   void doneUpdate(WWidget *w);
   void updateFormObjects(WWebWidget *w, bool checkDescendants);
 
-  enum ResponseType { Page, Script, Update };
-
   void updateFormObjectsList(WApplication *app);
   const FormObjectsMap& formObjects() const;
 
@@ -58,18 +57,19 @@ public:
   void letReloadHTML(WebResponse& request, bool newSession);
 
   bool isDirty() const;
+  int  pageId() const { return pageId_; }
 
-  void serveResponse(WebResponse& request, ResponseType responseType);
-  void serveError(WebResponse& request, const std::exception& error,
-		  ResponseType responseType);
-  void serveError(WebResponse& request, const std::string& message,
-		  ResponseType responseType);
+  void serveResponse(WebResponse& request);
+  void serveError(WebResponse& request, const std::exception& error);
+  void serveError(WebResponse& request, const std::string& message);
+  void serveLinkedCss(WebResponse& request);
 
   void setCookie(const std::string name, const std::string value,
 		 int maxAge, const std::string domain,
 		 const std::string path);
 
   bool preLearning() const { return learning_; }
+  void learningIncomplete();
 
   void ackUpdate(int updateId);
 
@@ -88,9 +88,9 @@ private:
   };
 
   WebSession& session_;
-  bool        visibleOnly_;
+  bool        visibleOnly_, rendered_;
   int         twoPhaseThreshold_;
-  int         expectedAckId_;
+  int         pageId_, expectedAckId_;
 
   std::vector<Cookie> cookiesToSet_;
 
@@ -99,6 +99,7 @@ private:
   bool           formObjectsChanged_;
 
   void setHeaders(WebResponse& request, const std::string mimeType);
+  void setCaching(WebResponse& response, bool allowCache);
 
   void serveJavaScriptUpdate(WebResponse& response);
   void serveMainscript(WebResponse& response);
@@ -106,14 +107,14 @@ private:
   void serveMainpage(WebResponse& response);
   void serveMainAjax(WebResponse& response);
   void serveWidgetSet(WebResponse& request);
-  void streamCommJs(WApplication *app, std::ostream& out);
   void collectJavaScript();
 
   void collectChanges(std::vector<DomElement *>& changes);
 
   void collectJavaScriptUpdate(std::ostream& out);
   void loadStyleSheets(std::ostream& out, WApplication *app);
-  void loadScriptLibraries(std::ostream& out, WApplication *app, bool start);
+  int loadScriptLibraries(std::ostream& out, WApplication *app,
+			  int count = -1);
   void updateLoadIndicator(std::ostream& out, WApplication *app, bool all);
   void setJSSynced(bool invisibleToo);
 
@@ -125,19 +126,23 @@ private:
   void              collectJS(std::ostream *js);
 
   void setPageVars(FileServe& page);
-  void setBootVars(WebResponse& response, FileServe& boot);
+  void streamBootContent(WebResponse& response, 
+			 FileServe& boot, bool hybrid);
 
   std::string headDeclarations() const;
+  std::string bodyClassRtl() const;
 
   typedef std::set<WWidget *> UpdateMap;
   UpdateMap updateMap_;
-  bool      learning_;
+  bool      learning_, learningIncomplete_;
   bool      moreUpdates_;
 
   std::string safeJsStringLiteral(const std::string& value);
 
 public:
   std::string       learn(WStatelessSlot* slot);
+
+  friend class WApplication;
 };
 
 }
